@@ -1,3 +1,4 @@
+
 (function() {
 
     function sendValue(value) {
@@ -27,7 +28,6 @@
       
       Streamlit.setFrameHeight(height);
       var card=await waitForBody('.card')
-      Streamlit.setComponentReady();
       document.querySelector("body").style.display='';
       card.style.height=height+"px";
       const titled = document.querySelector(".title span");
@@ -49,37 +49,39 @@
       if(isNaN(value)){
         vald.innerText=value;
         if(animate==true)
-          animateText(vald,animateDuration)
+          animateText(vald,animateDuration);
       }
       else{
-        oldVal=parseFloat(vald.innerText)
+        oldVal=parseFloat(vald.innerText);
         if(animate==true)
-          animateValue(vald,oldVal,value,animateDuration,unit)
+          animateValue(vald,oldVal,value,animateDuration,unit);
         else
-          vald.innerText=value  + unit
+          vald.innerText=value  + unit;
       }
       
       pgb.style.width=progress+"%";
       if(showProgress==false){
-        pgb.style.display='none'
+        pgb.style.display='none';
+      }
+      else{
+        pgb.style.display='';
       }
-      else[
-        pgb.style.display=''
-      ]
       if(showIcon==false){
-        iconParent.style.display='none'
+        iconParent.style.display='none';
       }
       else{
         setTimeout(()=>{
-        icond.className='fa'
+        icond.className='fa';
         icon.split(' ').forEach(element => {
           icond.classList.add(element);
         });
-        iconParent.style.display=''
-        iconParent.style.top=(body.clientHeight*(iconTop/100)) - (icond.clientHeight/2) +'px'
-        iconParent.style.left=(body.clientWidth*(iconLeft/100)) - (icond.clientWidth/2) +'px'
-        icond.style.color=iconColor
-        icond.style.opacity=iconOpacity/100
+        iconParent.style.display='';
+        var rangeH=(body.clientHeight-icond.clientHeight-pgb.clientHeight)*(iconTop/100)
+        iconParent.style.top=Math.max(rangeH,0)+'px';
+        var rangeV=(body.clientWidth-icond.clientWidth)*(iconLeft/100)
+        iconParent.style.left=Math.min(rangeV,body.clientWidth-icond.clientWidth)+'px';
+        icond.style.color=iconColor;
+        icond.style.opacity=iconOpacity/100;
       },300)
       }
     }
@@ -151,5 +153,6 @@
     }
 
     Streamlit.events.addEventListener(Streamlit.RENDER_EVENT, onRender);
+    Streamlit.setComponentReady();
 })();
 
